aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/script/run.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'libbuild2/script/run.hxx')
-rw-r--r--libbuild2/script/run.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/libbuild2/script/run.hxx b/libbuild2/script/run.hxx
index aa11def..f41a3d0 100644
--- a/libbuild2/script/run.hxx
+++ b/libbuild2/script/run.hxx
@@ -39,7 +39,7 @@ namespace build2
// can be used in diagnostics.
//
// Optionally, execute the specified function at the end of the pipe,
// either after the last command or instead of it (last_cmd=false).
//
void
run (environment&,
@@ -47,7 +47,7 @@ namespace build2
const iteration_index*, size_t index,
const location&,
const function<command_function>& = nullptr,
- bool last_cmd = true);
+ bool replace_last_cmd = false);
bool
run_cond (environment&,
@@ -55,7 +55,7 @@ namespace build2
const iteration_index*, size_t index,
const location&,
const function<command_function>& = nullptr,
- bool last_cmd = true);
+ bool replace_last_cmd = false);
// Perform the registered special file cleanups in the direct order and
// then the regular cleanups in the reverse order.
@@ -39,7 +39,7 @@ namespace build2
//
// Optionally, execute the specified function at the end of the pipe,
- // either after the last command or instead of it (last_cmd=false).
+ // potentially instead of the last command (replace_last_cmd).
//
void